/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hudi.common.testutils;

import java.util.Iterator;
import java.util.List;
import java.util.stream.Stream;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

/**
 * Common assertion functions.
 */
public class Assertions {

  public static void assertStreamEquals(Stream<?> expected, Stream<?> actual, String message) {
    Iterator<?> iter1 = expected.iterator();
    Iterator<?> iter2 = actual.iterator();
    while (iter1.hasNext() && iter2.hasNext()) {
      assertEquals(iter1.next(), iter2.next(), message);
    }
    assertTrue(!iter1.hasNext() && !iter2.hasNext(), message);
  }

  public static void assertListEquals(List<?> expected, List<?> actual) {
    Iterator<?> iter1 = expected.iterator();
    Iterator<?> iter2 = actual.iterator();
    while (iter1.hasNext() && iter2.hasNext()) {
      assertEquals(iter1.next(), iter2.next());
    }
    assertTrue(!iter1.hasNext() && !iter2.hasNext());
  }
}
